=======
Credits
=======

Development Lead
----------------

* Thomas-Charles Fortier Filion <tcff_hydro@outlook.com> `@TC-FF <https://github.com/TC-FF>`_

Co-Developers
-------------

* Trevor James Smith <smith.trevorj@ouranos.ca> `@Zeitsperre <https://github.com/Zeitsperre>`_
* Gabriel Rondeau-Genesse <rondeau-genesse.gabriel@ouranos.ca> `@RondeauG <https://github.com/RondeauG>`_
* Sébastien Langlois `@sebastienlanglois <https://github.com/sebastienlanglois>`_

Contributors
------------

None yet. Why not be the first?
